{% extends 'django_spire/page/full_page.html' %}
{% load comment_tags %}

{% block page_content %}
    <div class="row mb-3">
        <div class="col">
            {% include 'django_spire/file/card/demo_detail_card.html' %}
        </div>
    </div>

    <div class="row g-lg-2">
        <div class="col-8">
            {% include 'django_spire/file/card/demo_filler_card.html' %}
        </div>
        <div class="col-4">
            {% include 'django_spire/file/card/demo_file_list_card.html' with queryset=file_list %}
        </div>
    </div>
{% endblock %}
