{% extends 'django_spire/theme/card/base_preview_card.html' %}

{% block card_title %}Badges{% endblock %}

{% block card_button %}
    {% url 'django_spire:theme:page:badges' as badges_url %}
    {% include 'django_spire/button/primary_button.html' with button_text='Full Preview' button_href=badges_url %}
{% endblock %}

{% block preview_card_icon %}bi bi-tag{% endblock %}

{% block preview_card_subtitle %}
    Badge Styles
{% endblock %}

{% block preview_card_description %}
    View all badge types and colors
{% endblock %}

{% block preview_card_content %}
    {% include 'django_spire/badge/primary_badge.html' with badge_text='Primary' badge_class='me-1' %}
    {% include 'django_spire/badge/secondary_badge.html' with badge_text='Secondary' badge_class='me-1' %}
    {% include 'django_spire/badge/accent_badge.html' with badge_text='Accent' badge_class='me-1' %}
    {% include 'django_spire/badge/success_badge.html' with badge_text='Success' badge_class='me-1' %}
    {% include 'django_spire/badge/warning_badge.html' with badge_text='Warning' badge_class='me-1' %}
    {% include 'django_spire/badge/danger_badge.html' with badge_text='Danger' badge_class='me-1' %}
    {% include 'django_spire/badge/primary_outlined_badge.html' with badge_text='Outlined' badge_class='me-1' %}
    {% include 'django_spire/badge/secondary_outlined_badge.html' with badge_text='Secondary' badge_class='me-1' %}
{% endblock %}
