[data-theme="dark"] {
    --app-primary: #cba6f7;
    --app-primary-soft: #262034;
    --app-primary-dark: #a385d8;

    --app-secondary: #a6adc8;
    --app-secondary-soft: #3a3d4f;
    --app-secondary-dark: #7f849c;

    --app-accent: #f38ba8;
    --app-accent-soft: #2f2026;
    --app-accent-dark: #e06b75;

    --app-success: #a6e3a1;
    --app-success-soft: #222e23;
    --app-success-dark: #81c784;

    --app-warning: #f9e2af;
    --app-warning-soft: #3d3826;
    --app-warning-dark: #f4d47c;

    --app-danger: #f38ba8;
    --app-danger-soft: #2f2026;
    --app-danger-dark: #e06b75;

    --app-layer-one: #181825;
    --app-layer-two: #313244;
    --app-layer-three: #45475a;
    --app-layer-four: #585b70;

    --app-alt-layer-one: #11111b;
    --app-alt-layer-two: #1e1e2e;
    --app-alt-layer-three: #393952;
    --app-alt-layer-four: #4a4b61;

    --app-card-header: #313244;

    --app-default-attribute-title-color: #cdd6f4;
    --app-default-button-text-color: #1e1e2e;
    --app-default-text-color: #cdd6f4;
    --app-default-alt-text-color: #bac2de;
    --app-default-link-color: #cba6f7;
    --app-default-link-hover-color: #f38ba8;

    --app-inverted-text-color: #1e1e2e;
    --app-inverted-alt-text-color: #313244;

    --app-side-navigation-bg-color: #181825;
    --app-side-navigation-text-color: #cdd6f4;
    --app-side-navigation-link-color: #cdd6f4;
    --app-side-navigation-link-hover-color: #cba6f7;

    --app-top-navigation-bg-color: #181825;
    --app-top-navigation-text-color: #cdd6f4;
    --app-top-navigation-link-color: #cba6f7;
    --app-top-navigation-link-hover-color: #f38ba8;

    --app-footer-bg-color: #181825;
    --app-footer-text-color: #cdd6f4;
    --app-footer-link-color: #cba6f7;
    --app-footer-link-hover-color: #f38ba8;

    --app-table-row-color: #1e1e2e;
    --app-table-row-alt-color: #313244;
    --app-table-row-hover-color: #45475a;

    --bs-border-color: #585b70;

    --app-shadow-light: rgba(0, 0, 0, 0.3);
    --app-shadow-medium: rgba(0, 0, 0, 0.5);
    --app-shadow-heavy: rgba(0, 0, 0, 0.7);
    --app-shadow-navigation: rgba(0, 0, 0, 0.9);

    --app-border-translucent-light: rgba(88, 91, 112, 0.3);
    --app-focus-ring-primary: rgba(203, 166, 247, 0.25);
}
