# Generated by Django 5.2.1 on 2025-05-15 20:20

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('django_spire_notification', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='SmsNotification',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('to_phone_number', models.CharField(blank=True, max_length=11)),
                ('notification', models.OneToOneField(editable=False, on_delete=django.db.models.deletion.CASCADE, related_name='sms', related_query_name='sms', to='django_spire_notification.notification')),
            ],
            options={
                'verbose_name': 'SMS Notification',
                'verbose_name_plural': 'SMS Notifications',
                'db_table': 'django_spire_notification_sms',
            },
        ),
    ]
