<li class="nav-item d-none d-md-block">
    <form
        class="form-inline search-box"
        method="get"
        action="{% url 'search' %}"
    >
        <input
            class="form-control rounded-pill search-input fs--1"
            name="query"
            type="search"
            placeholder="Search..."
            aria-label="Search"
        >
    </form>
</li>
