<form
    method="post"
    class="row"
    x-data="{
        should_delete: new GlueBooleanField('should_delete', {value: 'true'})
    }"
>
    {% csrf_token %}
    <div class="col-12">
        {{ form_description }}
    </div>
    <div hidden>
        {% include 'django_glue/form/field/select_field.html' with glue_field='should_delete' %}
    </div>
    <div class="col-12 mt-2">
        {% include 'django_spire/contrib/form/button/form_submit_button.html' %}
    </div>
</form>
