{% extends 'django_spire/container/container.html' %}

{% block container_title %}
	Import Form
{% endblock %}

{% block container_content %}
	{% include 'django_spire/knowledge/entry/form/import_form.html' %}
{% endblock %}
